Changelog
=========


(unreleased)
------------
- Remove unnecessary files. [Paul Magister]


0.0.2 (2025-06-20)
------------------
- Merge pull request #1 from
  pamagister/dependabot/github_actions/actions/setup-python-5. [Paul
  Magister]

  Bump actions/setup-python from 4 to 5
- Bump actions/setup-python from 4 to 5. [dependabot[bot]]

  Bumps [actions/setup-python](https://github.com/actions/setup-python) from 4 to 5.
  - [Release notes](https://github.com/actions/setup-python/releases)
  - [Commits](https://github.com/actions/setup-python/compare/v4...v5)

  ---
  updated-dependencies:
  - dependency-name: actions/setup-python
    dependency-version: '5'
    dependency-type: direct:production
    update-type: version-update:semver-major
  ...
- Remove unnecessary files. [Paul Magister]


0.0.1 (2025-06-20)
------------------
- Rename project. [Paul Magister]
- Initial commit. [Paul Magister]


